@@ -28,8 +28,7 @@ from raven.utils.encoding import to_string
 from sentry import app
 from sentry.constants import (
     STATUS_RESOLVED, STATUS_UNRESOLVED, MINUTE_NORMALIZATION,
-    MAX_EXTRA_VARIABLE_SIZE, LOG_LEVELS, DEFAULT_LOGGER_NAME,
-    MAX_CULPRIT_LENGTH)
+    LOG_LEVELS, DEFAULT_LOGGER_NAME, MAX_CULPRIT_LENGTH)
 from sentry.db.models import BaseManager
 from sentry.processors.base import send_group_processors
 from sentry.signals import regression_signal
@@ -264,7 +263,8 @@ class GroupManager(BaseManager, ChartMixin):
             # throw it away
             data['extra'] = {}
 
-        trim_dict(data['extra'], max_size=MAX_EXTRA_VARIABLE_SIZE)
+        trim_dict(
+            data['extra'], max_size=settings.SENTRY_MAX_EXTRA_VARIABLE_SIZE)
 
         if 'sentry.interfaces.Exception' in data:
             if 'values' not in data['sentry.interfaces.Exception']:
@@ -843,6 +843,7 @@ class InstanceMetaManager(BaseManager):
     def unset_value(self, instance, key):
         self.filter(**{self.field_name: instance, 'key': key}).delete()
         if instance.pk not in self.__metadata:
+            cache.delete(self._make_key(instance))
             return
         self.__metadata[instance.pk].pop(key, None)
         cache.set(self._make_key(instance), self.__metadata[instance.pk])
@@ -859,6 +860,7 @@ class InstanceMetaManager(BaseManager):
             inst.update(value=value)
 
         if instance.pk not in self.__metadata:
+            cache.delete(self._make_key(instance))
             return
         self.__metadata[instance.pk][key] = value
         cache.set(self._make_key(instance), self.__metadata[instance.pk])
@@ -879,7 +881,7 @@ class InstanceMetaManager(BaseManager):
                         self.field_name: instance_id,
                     })
                 )
-                cache.add(cache_key, result)
+                cache.set(cache_key, result)
             self.__metadata[instance_id] = result
         return self.__metadata.get(instance_id, {})
 
