@@ -8,7 +8,7 @@
         defaults: {
             count: 0,
             version: 0,
-            usersSeen: null,
+            annotations: [],
             tags: [],
             versions: [],
             hasSeen: false,
