@@ -9,11 +9,12 @@ sentry.utils.avatar
 import hashlib
 import urllib
 
+from django.conf import settings
+
 
 def get_gravatar_url(email, size=None, default='mm'):
-    base = 'https://secure.gravatar.com'
-
-    gravatar_url = "%s/avatar/%s" % (base, hashlib.md5(email.lower()).hexdigest())
+    gravatar_url = "%s/avatar/%s" % (settings.SENTRY_GRAVATAR_BASE_URL,
+                                     hashlib.md5(email.lower()).hexdigest())
 
     properties = {}
     if size:
