@@ -78,7 +78,7 @@ class NotificationSettingsForm(forms.Form):
         widget=forms.Select(attrs={'class': 'input-xxlarge'}))
     subscribe_notes = forms.ChoiceField(
         choices=(
-            ('1', _('Get notified about new notes on events I\'ve seen')),
+            ('1', _('Get notified about new notes')),
             ('0', _('Do not subscribe to note notifications')),
         ), required=False,
         widget=forms.Select(attrs={'class': 'input-xxlarge'}))
@@ -132,7 +132,7 @@ class NotificationSettingsForm(forms.Form):
 class AccountSettingsForm(forms.Form):
     old_password = forms.CharField(label=_('Current password'), widget=forms.PasswordInput)
     email = forms.EmailField(label=_('Email'))
-    first_name = forms.CharField(required=True, label=_('Name'))
+    first_name = forms.CharField(required=True, label=_('Name'), max_length=30)
     new_password = forms.CharField(label=_('New password'), widget=forms.PasswordInput, required=False)
 
     def __init__(self, user, *args, **kwargs):
